@@ -86,25 +86,28 @@ class Teacher(abstract.Teacher):
             return Teacher.ERR_NO_INTERVALLS
         last_question = self.m_interval
         last_tonika = self.m_tonika
-        L, H = utils.adjust_low_high_to_irange(L, H, self.get_list('intervals'))
         while 1:
             # in this loop we will try to make a question that is not the
             # same that the last one.
-            if self.get_bool("lock-to-key"):
-                self.m_tonika, self.m_interval = \
-                    utils.random_tonic_and_interval_in_key(L, H,
-                        self.get_list('intervals'),
-                        mpd.MusicalPitch.new_from_int(self.get_int("lock-to-key-note")),
-                        solfege.utils.random_tonic_and_interval_in_key.key_data.keys()[:][self.get_int("lock-to-key-scaletype")])
-            else:
-                self.m_tonika, self.m_interval = \
-                      utils.random_tonika_and_interval(L, H,
-                        self.get_list('intervals'))
+            try:
+                if self.get_bool("lock-to-key"):
+                    self.m_tonika, self.m_interval = \
+                        utils.random_tonic_and_interval_in_key(L, H,
+                            self.get_list('intervals'),
+                            mpd.MusicalPitch.new_from_int(self.get_int("lock-to-key-note")),
+                            solfege.utils.key_data.keys()[:][self.get_int("lock-to-key-scaletype")])
+                else:
+                    self.m_tonika, self.m_interval = \
+                          utils.random_tonika_and_interval(L, H,
+                            self.get_list('intervals'))
+            except solfege.utils.NoPossibleIntervals, e:
+                solfege.win.display_error_message2(_("Exercise configuration problem"), unicode(e))
+                return self.ERR_NO_INTERVALLS
             if last_question is None:
                 break
             if (self.m_interval == last_question
                 and self.m_tonika == last_tonika) \
-                and (len(self.get_list('intervals')) > 1 or (H - L) > 1):
+                and (len(self.get_list('intervals')) > 1):
                 continue
             break
         assert self.m_tonika
@@ -229,8 +232,8 @@ class Gui(abstract.IntervalGui):
             # the statistics viewer can't handle it. It is no big deal
             # to fix it, but then the statistics can become almost unreadable
             # because of so many intervals.
-            if not -17 < interval < 17:
-                self.g_flashbar.flash(_("Ignoring intervals greater than major tenth."))
+            if not (mpd.interval.min_interval < interval <= mpd.interval.max_interval):
+                self.g_flashbar.flash(_("Ignoring intervals greater than double octave."))
                 self.g_input.forget_last_tone()
                 return
             if self.m_t.q_status == self.QSTATUS_NO:
@@ -274,7 +277,7 @@ class Gui(abstract.IntervalGui):
             return
         if solfege.app.m_test_mode:
             self.g_new.hide()
-        if isinstance(self.g_input, inputwidgets.IntervalButtonsWidget):
+        if hasattr(self.g_input, 'use_users_vocal_range'):
             g = self.m_t.new_question(self.get_string('user/lowest_pitch'),
                                       self.get_string('user/highest_pitch'))
         else:
@@ -314,11 +317,9 @@ class Gui(abstract.IntervalGui):
         super(Gui, self).on_start_practise()
         if self.m_t.m_custom_mode:
             self.g_ask_for_frame.show()
-            self.g_lock_to_key_hbox.show()
         else:
             self.m_t.m_statistics.reset_session()
             self.g_ask_for_frame.hide()
-            self.g_lock_to_key_hbox.hide()
         self.g_statview.g_heading.set_text("%s - %s" % (_("Harmonic interval"), self.m_t.m_P.header.title))
         self.std_buttons_start_practise()
         if solfege.app.m_test_mode:
